@@ -1058,8 +1058,7 @@ namespace Oxygen
     {
         #if OXYGEN_HAVE_X11
         #if QT_VERSION >= 0x050000
-        static bool isX11 = QApplication::platformName() == QStringLiteral("xcb");
-        return isX11;
+        return QX11Info::isPlatformX11();
         #else
         return true;
         #endif
